@@ -64,6 +64,13 @@ meta_comp_window_lookup (MetaCompScreen *info,
     return window;
 }
 
+MetaCompWindow *
+meta_comp_screen_lookup_window   (MetaCompScreen *info,
+				  Window          xwindow)
+{
+    return meta_comp_window_lookup (info, xwindow);
+}
+
 #if 0
 static void
 update_frame_counter (void)
@@ -148,7 +155,7 @@ repaint (gpointer data)
   cm_state_enable_depth_buffer_update (state);
   
   g_object_unref (state);
-  
+
   ws_window_gl_swap_buffers (info->gl_window);
   glFinish();
   
@@ -407,12 +414,16 @@ meta_comp_screen_restack (MetaCompScreen *info,
 			  Window	  window,
 			  Window	  above_this)
 {
+  MetaCompWindow *comp_window = find_comp_window (info, window);
+  MetaCompWindow *above_comp_window = find_comp_window (info, above_this);
   CmNode *window_node = find_node (info, window);
   CmNode *above_node  = find_node (info, above_this);
-  
-#if 0
-  g_print ("restack %lx over %lx \n", window, above_this);
-#endif
+
+  if ((comp_window && meta_comp_window_stack_frozen (comp_window)) ||
+      (above_comp_window && meta_comp_window_stack_frozen (above_comp_window)))
+  {
+      return;
+  }
   
 #if 0
   dump_stacking_order (info->stacker->children);
@@ -498,12 +509,30 @@ print_child_titles (WsWindow *window)
     }
 }
 
+typedef struct
+{
+    MetaCompScreen *cscreen;
+    XID		    xid;
+} DestroyData;
+
+static void
+on_window_destroy (MetaCompWindow *comp_window,
+		   gpointer        closure)
+{
+    DestroyData *data = closure;
+    CmNode *node = meta_comp_window_get_node (comp_window);
+    
+    cm_stacker_remove_child (data->cscreen->stacker, node);
+    g_hash_table_remove (data->cscreen->windows_by_xid, (gpointer)data->xid);
+}
+
 void
 meta_comp_screen_add_window (MetaCompScreen *info,
 			     Window	     xwindow)
 {
   WsDrawable *drawable;
   MetaCompWindow *comp_window;
+  DestroyData *data;
   
   ws_display_begin_error_trap (info->display);
   
@@ -525,8 +554,13 @@ meta_comp_screen_add_window (MetaCompScreen *info,
 #endif
       goto out;
     }
+
+  data = g_new (DestroyData, 1);
+  data->cscreen = info;
+  data->xid = WS_RESOURCE_XID (drawable);
   
-  comp_window = meta_comp_window_new (info->meta_screen->display, drawable);
+  comp_window = meta_comp_window_new (info->meta_screen, drawable,
+				      on_window_destroy, data);
   
   g_hash_table_insert (info->windows_by_xid, (gpointer)WS_RESOURCE_XID (drawable), comp_window);
   
@@ -558,14 +592,7 @@ meta_comp_screen_remove_window (MetaCompScreen *info,
   MetaCompWindow *comp_window = meta_comp_window_lookup (info, xwindow);
   
   if (comp_window)
-    {
-      CmNode *node = meta_comp_window_get_node (comp_window);
-      
-      cm_stacker_remove_child (info->stacker, node);
       meta_comp_window_free (comp_window);
-    
-      g_hash_table_remove (info->windows_by_xid, (gpointer)xwindow);
-    }
 }
 
 void
@@ -629,14 +656,10 @@ void
 meta_comp_screen_unmap (MetaCompScreen *info,
 			Window		xwindow)
 {
-  CmDrawableNode *node = CM_DRAWABLE_NODE (find_node (info, xwindow));
-  
-#if 0
-  g_print ("unmapping: %lx\n", xwindow);
-#endif
-  
-  if (node)
-    cm_drawable_node_set_viewable (node, FALSE);
+    MetaCompWindow *window = find_comp_window (info, xwindow);
+
+    if (window)
+	meta_comp_window_hide (window);
 }
 
 void
@@ -650,31 +673,5 @@ meta_comp_screen_set_target_rect (MetaCompScreen *info,
     cm_drawable_node_set_scale_rect (node, rect);
 }
 
-void
-meta_comp_screen_set_explode (MetaCompScreen *info,
-			      Window xwindow,
-			      gdouble level)
-{
-  CmDrawableNode *node = CM_DRAWABLE_NODE (find_node (info, xwindow));
-  
-  if (node)
-    {
-#if 0
-      g_print ("level: %f\n", level);
-#endif
-      
-      cm_drawable_node_set_explosion_level (node, level);
-    }
-}
-
-void
-meta_comp_screen_hide_window (MetaCompScreen *info,
-			      Window          xwindow)
-{
-  CmDrawableNode *node = CM_DRAWABLE_NODE (find_node (info, xwindow));
-  
-  cm_drawable_node_set_viewable (node, FALSE);
-}
-
 #endif
 
