@@ -138,6 +138,9 @@ struct _MetaWindow
   /* Whether we're trying to constrain the window to be on a single xinerama */
   guint require_on_single_xinerama : 1;
 
+  /* Whether we're trying to constrain the window's titlebar to be onscreen */
+  guint require_titlebar_visible : 1;
+
   /* Whether we're sticky in the multi-workspace sense
    * (vs. the not-scroll-with-viewport sense, we don't
    * have no stupid viewports)
@@ -146,6 +149,7 @@ struct _MetaWindow
 
   /* Minimize is the state controlled by the minimize button */
   guint minimized : 1;
+  guint was_minimized : 1;
   guint tab_unminimized : 1;
 
   /* Whether the window is mapped; actual server-side state
@@ -400,6 +404,10 @@ void        meta_window_unstick            (MetaWindow  *window);
 
 void        meta_window_activate           (MetaWindow  *window,
                                             guint32      current_time);
+void        meta_window_activate_with_workspace (MetaWindow *window,
+                                            guint32          current_time,
+                                            MetaWorkspace   *workspace);   
+                                                                                    
 void        meta_window_make_fullscreen    (MetaWindow  *window);
 void        meta_window_unmake_fullscreen  (MetaWindow  *window);
 
